"""
Django settings for KeRS project.

Generated by 'django-admin startproject' using Django 3.0.8.

For more information on this file, see
https://docs.djangoproject.com/en/3.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.0/ref/settings/
"""

import os

from django.core.exceptions import ImproperlyConfigured


# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '2r@t7^g4-@980!oo-v!1+wj+0o^s&m(+yyyt#2&k2e!ao*b$g5'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = []

# Application definition

OWN_APPS = [
    'events',
    'users',
    'oauth'
]

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django_celery_beat'
] + OWN_APPS

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'KeRS.urls'

TEMPLATES = [
    {
        'BACKEND':  'django.template.backends.django.DjangoTemplates',
        'DIRS':     [os.path.join(BASE_DIR, 'templates')]
        ,
        'APP_DIRS': True,
        'OPTIONS':  {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'KeRS.wsgi.application'

# Database
# https://docs.djangoproject.com/en/3.0/ref/settings/#databases

if os.getenv('KERS_DB_BACKEND', 'mysql') == 'sqlite3':
    DATABASES = {
        'default': {
            'ENGINE':   'django.db.backends.sqlite3',
            'NAME':     os.getenv('KERS_SQLITE_FILE', 'kers.sqlite3'),
        }
    }
else:
    DATABASES = {
        'default': {
            'ENGINE':   'django.db.backends.mysql',
            'NAME':     os.getenv('DATABASE_NAME', 'kers'),
            'USER':     os.getenv('DATABASE_USER', 'kers'),
            'PASSWORD': os.getenv('DATABASE_PASSWORD', 'kers'),
            'HOST':     os.getenv('DATABASE_HOST', '127.0.0.1'),
            'PORT':     os.getenv('DATABASE_PORT', '3306'),
        }
    }

# Password validation
# https://docs.djangoproject.com/en/3.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization
# https://docs.djangoproject.com/en/3.0/topics/i18n/

LANGUAGE_CODE = 'nl-be'

TIME_ZONE = 'Europe/Brussels'

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.0/howto/static-files/

STATIC_URL = '/static/'
STATICFILES_DIRS = [
    os.path.join(BASE_DIR, "static"),
]

# Celery

CELERY_BROKER = os.getenv('CELERY_BROKER', 'redis://localhost:6379/0')
CELERY_BACKEND = os.getenv('CELERY_BACKEND', 'redis://localhost:6379/1')

# OAuth

BASE_URL = os.getenv('BASE_URL', 'http://localhost:8000')

AUTH_USER_MODEL = 'users.CustomUser'

_BASE_OAUTH_URL = os.getenv('OAUTH_BASE_URL', 'https://adams.ugent.be/oauth')

OAUTH = {
    'USER_API_URI':     f'{_BASE_OAUTH_URL}/api/current_user/',
    'ACCESS_TOKEN_URI': f'{_BASE_OAUTH_URL}/oauth2/token/',
    'AUTHORIZE_URI':    f'{_BASE_OAUTH_URL}/oauth2/authorize/',
    'REDIRECT_URI':     f'{BASE_URL}/login/zeus/authorized',
    'CLIENT_ID':        os.getenv('OAUTH_CLIENT_ID', 'tomtest'),
    'CLIENT_SECRET':    os.getenv('OAUTH_CLIENT_SECRET', 'blargh'),
    'REFERER':          f'{BASE_URL}/login/zeus/register'
}
